..
    Copyright (c) 2018 Bobby Noelte
    SPDX-License-Identifier: Apache-2.0

.. _cogeno_scripting:

Scripting
#########

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   functions
   modules
   templates
